# frozen_string_literal: true

module GoNative
  module Plugins
    module IOS
      class Publish
        extend DSL::Serviceable
        include Release
        
        def call
          assert_valid_plugin!
          assert_staging_clear!
          build_framework!
          release_pod!
        end

        def assert_valid_plugin!
          return if File.file?('create-framework.sh')
          
          raise Error, "File 'create-framework.sh' does not exist. Please make sure this is a valid GoNative plugin directory"
        end
        
        def assert_staging_clear!
          return if `git status --porcelain`.empty?

          raise Error, "There are uncommitted changes in the repository"
        end
        
        def build_framework!
          Utils::UI.info 'Building framework'
          return if system('sh create-framework.sh >/dev/null 2>/dev/null')
          
          raise Error, "Error building framework. Please run the create-framework file manually to fix any errors"
        end
      end
    end
  end
end
